@@ -71,7 +71,10 @@ for disk in ${disks}; do
   nr_of_partitions=$(lsblk -lno name,type /dev/${disk} | grep -c 'part$')
   if [ "${nr_of_partitions}" -eq "1" ]; then
     partition=$(lsblk -lno name,type /dev/${disk} | grep 'part$' | awk '{print $1}')
-    if file --special-files --dereference /dev/$partition | grep --quiet --ignore-case "xfs"; then
+    # note, use 'file' instead of 'lsblk'
+    # 'lsblk -lno fstype /dev/$partition' sometimes returns empty, see CM-34808
+    # "SGI XFS filesystem data" string is from 'file' program source, see CM-41737
+    if file --special-files --dereference /dev/$partition | grep --quiet --ignore-case "SGI XFS filesystem data"; then
       if [ "$(lsblk -lno label /dev/${partition})" != "BCMINSTALLER" ]; then
         echo ", resizing partition /dev/${partition}."
         echo "resizepart 1 -1" | parted /dev/${disk}
