@@ -25,6 +25,7 @@ import textwrap
 import time
 
 import paramiko
+import tenacity
 
 from clusterondemand import localpath
 from clusterondemand.codoutput.sortingutils import SSHAlias
@@ -39,8 +40,6 @@ from clusterondemand.utils import (
 from clusterondemandconfig import ConfigNamespace, config
 from clusterondemandconfig.configuration_validation import must_be_nonnegative
 
-from .decorators import retry
-
 clusterssh_ns = ConfigNamespace("cluster.ssh")
 
 clusterssh_ns.add_parameter(
@@ -625,9 +624,13 @@ class SSHExecutor(object):
         self._ssh_client.set_missing_host_key_policy(paramiko.AutoAddPolicy())
         connected = False
 
-        @retry(timeout=self._connect_timeout, wait_between_retries=self._wait_between_connect_retries)
-        def connect_wait(time_left, **kwargs):
-            log.debug(f"Creating an ssh connection to {self._user}@{self._host} ({time_left:.0f}s left)")
+        @tenacity.retry(
+            stop=tenacity.stop_after_delay(self._connect_timeout),
+            wait=tenacity.wait_fixed(self._wait_between_connect_retries),
+            before_sleep=tenacity.before_sleep_log(log, logging.DEBUG),
+            reraise=True,
+        )
+        def connect_wait():
             self._ssh_client.connect(
                 self._host,
                 username=self._user,
@@ -635,11 +638,12 @@ class SSHExecutor(object):
                 password=self._password,
                 timeout=self._connect_timeout,
             )
-            log.debug(f"Ssh connection to {self._user}@{self._host} established")
 
         try:
+            log.debug(f"Creating an SSH connection to {self._user}@{self._host} (timeout {self._connect_timeout}s)")
             connect_wait()
             connected = True
+            log.debug(f"SSH connection to {self._user}@{self._host} established")
         except paramiko.AuthenticationException as e:
             self._last_error = e
             raise SSHAuthenticationError(self._host) from e
