@@ -32,6 +32,7 @@ from subprocess import CalledProcessError, check_call
 from typing import Dict, List
 
 import netaddr
+import tenacity
 from dateutil.parser import parse
 from dateutil.tz import tzlocal, tzutc
 from six.moves import input
@@ -39,7 +40,7 @@ from six.moves import input
 from clusterondemand.exceptions import CODException
 from clusterondemandconfig import ConfigNamespace, config
 
-from .decorators import retry, static_vars
+from .decorators import static_vars
 
 log = logging.getLogger("cluster-on-demand")
 
@@ -312,25 +313,25 @@ def confirm_edge_creation():
 
 
 def wait_for_socket(ip, port, timeout, throw=False):
-    @retry(timeout=timeout, only_retry_on_exception=socket.error, wait_between_retries=1.0)
-    def try_to_connect(attempts, time_left):
+    @tenacity.retry(
+        stop=tenacity.stop_after_delay(timeout),
+        retry=tenacity.retry_if_exception_type(socket.error),
+        wait=tenacity.wait_fixed(1),
+        before_sleep=tenacity.before_sleep_log(log, logging.DEBUG),
+        reraise=True,
+    )
+    def try_to_connect():
         sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        sock.settimeout(1)
-
         try:
+            sock.settimeout(1)
             sock.connect((ip, port))
-            log.debug("Connection to %s:%s open. Finished waiting." % (ip, port))
-        except socket.timeout as e:
-            if 0 == attempts % 10:
-                log.debug("Connection to %s:%s is not yet open, waiting for %d seconds" % (ip, port, time_left))
-            raise type(e)("Timed out while waiting for %s:%s." % (ip, port))
-        except socket.error:
-            if 0 == attempts % 10:
-                log.debug("Connection to %s:%s is not yet open, waiting for %d seconds" % (ip, port, time_left))
-            raise
+        finally:
+            sock.close()
 
     try:
+        log.debug(f"Waiting for connection to {ip}:{port} to be opened, waiting for {timeout} seconds")
         try_to_connect()
+        log.debug(f"Connection to {ip}:{port} was opened successfully")
         return True
     except socket.timeout as e:
         if throw:
@@ -379,6 +380,8 @@ def get_package_type(bcm_distro):
         return "yum"
     if bcm_distro.upper().startswith("ROCKY"):
         return "yum"
+    elif bcm_distro.upper().startswith("ALMA"):
+        return "yum"
     elif bcm_distro.upper().startswith("SLES"):
         return "zypper"
     elif bcm_distro.upper().startswith("SL"):  # This has to come after SLES
